Index: /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.h
===================================================================
--- /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.h	(revision 8815)
+++ /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.h	(revision 8816)
@@ -9,6 +9,5 @@
 
 /* local prototypes: */
-void CreateNodalConstraintsx( Vec* pys, Nodes* nodes,int analysis_type);
+void CreateNodalConstraintsx( Vec* pys, Nodes* nodes,int configuration_type);
 
 #endif  /* _CREATENODALCONSTRAINTSX_H */
-
Index: /issm/trunk/src/c/modules/GroundingLineMigrationx/GroundingLineMigrationxUtils.cpp
===================================================================
--- /issm/trunk/src/c/modules/GroundingLineMigrationx/GroundingLineMigrationxUtils.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/GroundingLineMigrationx/GroundingLineMigrationxUtils.cpp	(revision 8816)
@@ -78,11 +78,11 @@
 	double*  potential_sheet_ungrounding=NULL;
 	int      numnods;
-	int      analysis_type;
+	int      configuration_type;
 
 	/*recover parameters: */
-	parameters->FindParam(&analysis_type,AnalysisTypeEnum);
+	parameters->FindParam(&configuration_type,ConfigurationTypeEnum);
 	
 	/*First, initialize vec_new_shelf_nodes, which will track which nodes have changed status: */
-	numnods=nodes->NumberOfNodes(analysis_type);
+	numnods=nodes->NumberOfNodes(configuration_type);
 	vec_potential_sheet_ungrounding=NewVec(numnods);
 
@@ -270,5 +270,5 @@
 	int i;
 	Element* element=NULL;
-	int analysis_type;
+	int configuration_type;
 	int numnods;
 	Vec vec_new_shelf_nodes=NULL;
@@ -280,8 +280,8 @@
 
 	/*recover parameters: */
-	parameters->FindParam(&analysis_type,AnalysisTypeEnum);
+	parameters->FindParam(&configuration_type,ConfigurationTypeEnum);
 
 	/*First, initialize vec_new_shelf_nodes, which will track which nodes have changed status: */
-	numnods=nodes->NumberOfNodes(analysis_type);
+	numnods=nodes->NumberOfNodes(configuration_type);
 	vec_new_shelf_nodes=NewVec(numnods);
 
@@ -313,5 +313,5 @@
 }
 /*}}}*/
-Vec        CreateNodesOnIceShelf(Nodes* nodes,int analysis_type){ //{{{1
+Vec CreateNodesOnIceShelf(Nodes* nodes,int configuration_type){ //{{{1
 
 	/*output: */
@@ -325,5 +325,5 @@
 
 	/*First, initialize nodes_on_iceshelf, which will track which nodes have changed status: */
-	numnods=nodes->NumberOfNodes(analysis_type);
+	numnods=nodes->NumberOfNodes(configuration_type);
 	nodes_on_iceshelf=NewVec(numnods);
 
@@ -331,5 +331,5 @@
 	for(i=0;i<nodes->Size();i++){
 		node=(Node*)nodes->GetObjectByOffset(i);
-		if(node->InAnalysis(analysis_type)){
+		if(node->InAnalysis(configuration_type)){
 			if(node->IsOnShelf()){
 				VecSetValue(nodes_on_iceshelf,node->Sid(),1.0,INSERT_VALUES);
Index: /issm/trunk/src/c/modules/NodesDofx/NodesDofx.cpp
===================================================================
--- /issm/trunk/src/c/modules/NodesDofx/NodesDofx.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/NodesDofx/NodesDofx.cpp	(revision 8816)
@@ -10,5 +10,5 @@
 #include "../../EnumDefinitions/EnumDefinitions.h"
 
-void NodesDofx(Nodes* nodes, Parameters* parameters,int analysis_type){
+void NodesDofx(Nodes* nodes, Parameters* parameters,int configuration_type){
 
 	int noerr=1;
@@ -17,16 +17,16 @@
 	
 	/*Do we have any nodes for this analysis type? :*/
-	if(nodes->NumberOfNodes(analysis_type)){ 
+	if(nodes->NumberOfNodes(configuration_type)){ 
 
 		/*Ensure that only for each cpu, the partition border nodes only will be taken into account once 
 		 * across the cluster. To do so, we flag all the clone nodes: */
-		nodes->FlagClones(analysis_type);
+		nodes->FlagClones(configuration_type);
 
 		/*Go through all nodes, and build degree of freedom lists. Each node gets a fixed number of dofs. When 
 		 *a  node has already been distributed dofs on one cpu, all other cpus with the same node cannot distribute it 
 		 *anymore. Use clone field to be sure of that: */
-		nodes->DistributeDofs(analysis_type,GsetEnum);
-		nodes->DistributeDofs(analysis_type,FsetEnum);
-		nodes->DistributeDofs(analysis_type,SsetEnum);
+		nodes->DistributeDofs(configuration_type,GsetEnum);
+		nodes->DistributeDofs(configuration_type,FsetEnum);
+		nodes->DistributeDofs(configuration_type,SsetEnum);
 	}
 
Index: /issm/trunk/src/c/modules/Reducevectorgtofx/Reducevectorgtofx.cpp
===================================================================
--- /issm/trunk/src/c/modules/Reducevectorgtofx/Reducevectorgtofx.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/Reducevectorgtofx/Reducevectorgtofx.cpp	(revision 8816)
@@ -13,5 +13,4 @@
 	/*variables: */
 	int i;
-	int analysis_type;
 	int configuration_type;
 	int fsize;
@@ -20,6 +19,6 @@
 	/*first figure out fsize: */
 	parameters->FindParam(&configuration_type,ConfigurationTypeEnum);
-	parameters->FindParam(&analysis_type,AnalysisTypeEnum);
 	fsize=nodes->NumberOfDofs(configuration_type,FsetEnum);
+	printf("%s\n",EnumToStringx(configuration_type));
 
 	if(fsize==0){
@@ -30,5 +29,5 @@
 		uf=NewVec(fsize);
 
-		if(nodes->NumberOfNodes(analysis_type)){ 
+		if(nodes->NumberOfNodes(configuration_type)){ 
 
 			/*serialize ug, so nodes can index into it: */
@@ -41,5 +40,5 @@
 
 				/*Check that this node corresponds to our analysis currently being carried out: */
-				if (node->InAnalysis(analysis_type)){
+				if (node->InAnalysis(configuration_type)){
 
 					/*For this object, reduce values for enum set Fset: */
@@ -47,12 +46,9 @@
 				}
 			}
-
 		}
+		/*Assemble vector: */
+		VecAssemblyBegin(uf);
+		VecAssemblyEnd(uf);
 	}
-
-	/*Assemble vector: */
-	VecAssemblyBegin(uf);
-	VecAssemblyEnd(uf);
-
 
 	/*Free ressources:*/
Index: /issm/trunk/src/c/modules/Reducevectorgtosx/Reducevectorgtosx.cpp
===================================================================
--- /issm/trunk/src/c/modules/Reducevectorgtosx/Reducevectorgtosx.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/Reducevectorgtosx/Reducevectorgtosx.cpp	(revision 8816)
@@ -13,5 +13,4 @@
 	/*variables: */
 	int i;
-	int analysis_type;
 	int configuration_type;
 	int ssize;
@@ -20,5 +19,4 @@
 	/*first figure out ssize: */
 	parameters->FindParam(&configuration_type,ConfigurationTypeEnum);
-	parameters->FindParam(&analysis_type,AnalysisTypeEnum);
 	ssize=nodes->NumberOfDofs(configuration_type,SsetEnum);
 
@@ -30,5 +28,5 @@
 		ys=NewVec(ssize);
 
-		if(nodes->NumberOfNodes(analysis_type)){ 
+		if(nodes->NumberOfNodes(configuration_type)){ 
 
 			/*serialize yg, so nodes can index into it: */
@@ -41,5 +39,5 @@
 
 				/*Check that this node corresponds to our analysis currently being carried out: */
-				if (node->InAnalysis(analysis_type)){
+				if (node->InAnalysis(configuration_type)){
 
 					/*For this object, reduce values for enum set Fset: */
@@ -48,9 +46,8 @@
 			}
 		}
+		/*Assemble vector: */
+		VecAssemblyBegin(ys);
+		VecAssemblyEnd(ys);
 	}
-
-	/*Assemble vector: */
-	VecAssemblyBegin(ys);
-	VecAssemblyEnd(ys);
 
 	/*Free ressources:*/
Index: /issm/trunk/src/c/modules/UpdateSpcsx/UpdateSpcsx.cpp
===================================================================
--- /issm/trunk/src/c/modules/UpdateSpcsx/UpdateSpcsx.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/UpdateSpcsx/UpdateSpcsx.cpp	(revision 8816)
@@ -13,11 +13,11 @@
 	
 	int i;
-	int analysis_type;
+	int configuration_type;
 	double* ys_serial=NULL;
 
 	/*retrieve parameters: */
-	parameters->FindParam(&analysis_type,AnalysisTypeEnum);
+	parameters->FindParam(&configuration_type,ConfigurationTypeEnum);
 
-	if(nodes->NumberOfNodes(analysis_type)){ 
+	if(nodes->NumberOfNodes(configuration_type)){ 
 
 		/*serialize ys, so nodes can index into it: */
@@ -30,5 +30,5 @@
 
 			/*Check that this node corresponds to our analysis currently being carried out: */
-			if (node->InAnalysis(analysis_type)){
+			if (node->InAnalysis(configuration_type)){
 
 				/*For this object, reset values of spc fields in the node: */

Index: /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.cpp
===================================================================
--- /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.cpp	(revision 8815)
+++ /issm/trunk/src/c/modules/CreateNodalConstraintsx/CreateNodalConstraintsx.cpp	(revision 8816)
@@ -10,5 +10,5 @@
 #include "../../EnumDefinitions/EnumDefinitions.h"
 
-void CreateNodalConstraintsx( Vec* pys, Nodes* nodes,int analysis_type){
+void CreateNodalConstraintsx( Vec* pys, Nodes* nodes,int configuration_type){
 
 	int i;
@@ -21,14 +21,14 @@
 
 	/*figure out how many dofs we have: */
-	numberofdofs=nodes->NumberOfDofs(analysis_type,SsetEnum);
+	numberofdofs=nodes->NumberOfDofs(configuration_type,SsetEnum);
 
 	/*allocate:*/
 	ys=NewVec(numberofdofs);
 
 	/*go through all nodes, and for the ones corresponding to this analysis_type, fill the 
 	 * constraints vector with the constraint values: */
 	for (i=0;i<nodes->Size();i++){
 		Node* node=(Node*)nodes->GetObjectByOffset(i);
-		if (node->InAnalysis(analysis_type)){
+		if (node->InAnalysis(configuration_type)){
 			node->CreateNodalConstraints(ys);
 		}
@@ -21,14 +21,14 @@
 	ys=NewVec(numberofdofs);
 
-	/*go through all nodes, and for the ones corresponding to this analysis_type, fill the 
+	/*go through all nodes, and for the ones corresponding to this configuration_type, fill the 
 	 * constraints vector with the constraint values: */
 	for (i=0;i<nodes->Size();i++){